@@ -7,7 +7,7 @@ cat("\n")
                  "Back to the previous step",
                  "Quit")
  cat("\n")
-  pick <- menu(file.menu, title = " << Statistical analysis (ANOVA(lm), 90%CI...) menu >> ")
+  pick <- menu(file.menu, title = " << Statistical analysis (ANOVA(lm), 90%CI...) menu >> ", graphics=TRUE)
     if (pick == 1){
       cat("\n")
         if(multiple){
