@@ -3,5 +3,5 @@ NCA.BANOVA<-function(Totalplot,Dose, ref_data, test_data, SingleRdata, SingleRda
 SingleTdata,SingleTdata1,xaxis, yaxis,rdata.split,tdata.split){
 
 NCA(Totalplot,Dose, ref_data, test_data, SingleRdata, SingleRdata1,SingleTdata,
-    SingleTdata1,xaxis, yaxis,rdata.split,tdata.split,Demo=FALSE, BANOVA=TRUE)
+    SingleTdata1,xaxis, yaxis,rdata.split,tdata.split,Demo=FALSE, BANOVA=TRUE,replicated=FALSE,MIX=FALSE)
 }
\ No newline at end of file
