@@ -1,5 +1,5 @@
 ##
-## will be called by NCAmenu(); demo for NCA
+## will be called by NCAmenu(); demo for NCA ONLY <--- YJ
 ##
 demomenu<-function(replicated=FALSE, parallel=FALSE, multiple=FALSE)
 {
@@ -19,7 +19,7 @@ Paralleldata<-NULL
                  "Back to the previous step",
                  "Quit")
  cat("\n")
-  pick <- menu(file.menu, title = " << Noncompartmental analysis (NCA)>> ")
+  pick <- menu(file.menu, title = "  << Method Selection for of lambda_z Estimation>> ", graphics=TRUE)
     description_NCAinput()
     
  if(replicated){
@@ -80,7 +80,10 @@ SingleTdata1$conc[SingleTdata1$conc == 0] <- NA
 SingleTdata1 <- na.omit(SingleTdata1)
 
 Totalplot<- rbind(SingleRdata,SingleTdata)              
-      
+###
+create.products_sum(Totalplot)
+###
+
    if (pick == 1){
         show(SingleRdata)
         show(SingleTdata)
@@ -171,7 +174,10 @@ Totalplot<- rbind(SingleRdata,SingleTdata)
       SingleTdata<-subset(SingleTdata0, time >=TlastD)
       
       Totalplot<- rbind(SingleRdata,SingleTdata)
-      
+###
+create.products_sum(Totalplot)
+###
+
     if (pick == 1){
         show(SingleRdata)
         show(SingleTdata)
@@ -257,6 +263,9 @@ Totalplot<- rbind(SingleRdata,SingleTdata)
       SingleTdata1$conc[SingleTdata1$conc == 0] <- NA
       SingleTdata1 <- na.omit(SingleTdata1)
       Totalplot<- rbind(SingleRdata,SingleTdata)
+###
+create.products_sum(Totalplot)
+###
       
     if (pick == 1){
         show(SingleRdata)
@@ -348,6 +357,9 @@ else{
      SingleRdata<-subset(SingleRdata0, time >=TlastD)
      SingleTdata<-subset(SingleTdata0, time >=TlastD)
      Totalplot<- rbind(SingleRdata0,SingleTdata0)
+###
+create.products_sum(Totalplot)
+###
       
     if (pick == 1){
         show(SingleRdata0)
@@ -433,6 +445,9 @@ else{
       SingleTdata1$conc[SingleTdata1$conc == 0] <- NA
       SingleTdata1 <- na.omit(SingleTdata1)
       Totalplot<- rbind(SingleRdata,SingleTdata)
+###
+create.products_sum(Totalplot)
+###
       
     if (pick == 1){
         show(SingleRdata)
