@@ -16,5 +16,5 @@ cat(" in this case. If so, please try another method next time.
 cat("*******************************************************************************\n")
 cat("\n")
 alarm(); alarm()
-readline(" Press Enter key to continue...")
+readline(" Press Enter to proceed...")
 }
\ No newline at end of file
